@@ -12,16 +12,19 @@ from .gamepad import ULGamepadLook  # noqa
 from .keyboard import KEYBOARD_EVENTS  # noqa
 from .keyboard import key_down  # noqa
 from .keyboard import key_pulse  # noqa
+from .keyboard import key_press  # noqa
 from .keyboard import key_tap  # noqa
 from .keyboard import key_up  # noqa
 from .mouse import LMB  # noqa
 from .mouse import MMB  # noqa
 from .mouse import MOUSE_EVENTS  # noqa
 from .mouse import RMB  # noqa
+from .mouse import MOUSE  # noqa
 from .mouse import get_mouse_position  # noqa
 from .mouse import mouse_down  # noqa
 from .mouse import mouse_moved  # noqa
 from .mouse import mouse_tap  # noqa
+from .mouse import mouse_press  # noqa
 from .mouse import mouse_up  # noqa
 from .mouse import mouse_wheel  # noqa
 from .mouse import set_mouse_position  # noqa
