@@ -33,14 +33,14 @@ def set_mouse_position(x: int, y: int, absolute: bool = False) -> None:
     )
 
 
-def get_mouse_position(absolute: bool = False) -> tuple:
+def get_mouse_position(absolute: bool = False) -> Vector:
     pos = logic.mouse.position
     if absolute:
-        return (
+        return Vector((
             int(pos[0] * render.getWindowWidth()),
             int(pos[1] * render.getWindowHeight())
-        )
-    return pos
+        ))
+    return Vector(pos)
 
 
 def mouse_moved(tap: bool = False) -> bool:
@@ -94,6 +94,25 @@ def mouse_down(button=events.LEFTMOUSE) -> bool:
     )
 
 
+def mouse_press(button=events.LEFTMOUSE, down=False) -> bool:
+    '''Detect mouse button tap or held down.
+
+    :param button: can be either `LMB`, `RMB` or `MMB` from `uplogic.input`
+
+    :returns: boolean
+    '''
+    button = MOUSE_BUTTONS.get(button, button)
+    return (
+        MOUSE_EVENTS[button].active or
+        MOUSE_EVENTS[button].activated or
+        MOUSE_EVENTS[button].active or
+        MOUSE_EVENTS[button].activated
+    ) if down else (
+        MOUSE_EVENTS[button].activated or
+        MOUSE_EVENTS[button].activated
+    )
+
+
 def mouse_up(button=events.LEFTMOUSE) -> bool:
     '''Detect mouse button released.
 
@@ -219,6 +238,9 @@ class ULMouse():
         return mouse_tap(MOUSE_BUTTONS[button])
 
 
+MOUSE = ULMouse()
+
+
 class ULMouseLook():
     """Automatically track the mouse movement and translate it to a rotate a
     body and optionally a head.
