@@ -1,6 +1,6 @@
 from uplogic.nodes import ULActionNode
 from uplogic.nodes import ULOutSocket
-from uplogic.utils import is_waiting
+from uplogic.utils import is_waiting, make_valid_name
 from uplogic.utils import is_invalid
 from uplogic.utils import not_met
 
@@ -17,6 +17,9 @@ class ULStartSubNetwork(ULActionNode):
     def get_done(self):
         return self.done
 
+    def setup(self, network):
+        self._network = network
+
     def evaluate(self):
         self.done = False
         condition = self.get_input(self.condition)
@@ -29,7 +32,14 @@ class ULStartSubNetwork(ULActionNode):
         self._set_ready()
         if is_invalid(game_object):
             return
-        network = game_object.get(f'IGNLTree_{logic_network_name}')
-        if network is not None:
+        tree_name = make_valid_name(logic_network_name)
+        network = game_object.get(f'IGNLTree_{tree_name}')
+        if network is None:
+            network = self._network.install_subnetwork(
+                game_object,
+                tree_name,
+                True
+            )
+        else:
             network.stopped = False
         self.done = True
