@@ -72,14 +72,14 @@ class ULTrackTo():
         target: GameObject or Vector,
         axis: int = 2,
         front: int = 1,
-        speed: float = 0
+        factor: float = 1
     ) -> None:
         self._axis = None
         self._target = None
         self.game_object = game_object
         self.target = target
         self.front = front
-        self.speed = speed
+        self.factor = factor
         self.axis = axis
 
     @property
@@ -121,7 +121,9 @@ class ULTrackTo():
 
 
 class ULSpring():
-    """Spring Physics Constraint.
+    """Spring Physics Constraint. The two objects connected by the string will
+    be pulled towards each other if the string is streched, optionally they will
+    be pushed apart when the spring is being compacted.
 
     :param `origin`: First connection point of the spring.
     :param `target`: Second connection point of the spring.
